Module rendering

Module rendering 

Structs

ClippedLineMaterial
Material used for tracked grids. It will clip beyond a certain distance from the camera, creating the illusion of an infinite grid.
ClippedLineMaterialUniform
Uniform for the ClippedLineMaterial
SimpleLineMaterial
Simple line material with no functionality beyond assigning a color

Constants

CLIPPED_LINE_SHADER_HANDLE
Handle for the clipped line shader
SIMPLE_LINE_SHADER_HANDLE
Handle for the simple line shader